<?php
/**
 * @file media_issuu/includes/MediaInternetIssuuHandler.inc
 * media_internet handler for Issuu.com.
 */

/**
 * Implementation of MediaInternetBaseHandler.
 *
 * @see hook_media_internet_providers()
 */
class MediaInternetIssuuHandler extends MediaInternetBaseHandler {
  /**
   * Check if a Issuu.com id is valid.
   * @todo implement function.
   *
   * @return
   *   Boolean.
   */
  static public function validURL($url) {
    $response = drupal_http_request($url, array('method' => 'HEAD'));
    if ($response->code == 404) {
      throw new MediaInternetValidationException("Issuu cannot be found. ");
    }
    return TRUE;
  }
  /**
   * Parse URL from Issuu.
   *
   * Issuu has following URL format:
   * http://issuu.com/<user>/docs/<doctitle>
   */
  public function parse($embedCode) {
    $patterns = array(
      '@issuu\.com/(.+)/docs/(.+)@i',
    );
    foreach ($patterns as $pattern) {
      preg_match($pattern, $embedCode, $matches);
      // @TODO: Parse is called often. Refactor so that valid ID is checked
      // when a video is added, but not every time the embedCode is parsed.
      if (isset($matches[0]) && isset($matches[1]) && isset($matches[2]) && self::validURL($embedCode)) {
         return file_stream_wrapper_uri_normalize('issuu://' . $matches[1] . '/docs/' . $matches[2]);
      }
    }
   }
  /**
   * Get file object.
   */
  public function getFileObject() {
    $uri = $this->parse($this->embedCode);
    $file = file_uri_to_object($uri, TRUE);
    // Try to default the file name to the issuu's title.
    $response = drupal_http_request($this->embedCode);
    if (!isset($response->error)) {
      // get <meta property="og:title" content="Dubbelpunt oktober2013 FC de leidingsploeg"> form $response->data
      $doc = new DOMDocument();
      libxml_use_internal_errors(true);
      $doc->loadHTML($response->data);
      libxml_clear_errors();
      foreach( $doc->getElementsByTagName('meta') as $meta ) { 
        if($meta->getAttribute('property') == 'og:title'){
          $title = $meta->getAttribute('content');
          $file->filename = truncate_utf8($title, 255);
        }
      }
    }
    return $file;
  }
  /**
   * Claim parsed embedCode.
   */
  public function claim($embed_code) {
    if ($this->parse($embed_code)) {
      return TRUE;
    }
  }
  /**
   * Save file.
   */
  public function save() {
    $file = $this->getFileObject();
    file_save($file);
    return $file;
  }
}
